@@ -1,5 +1,3 @@
-
-
 #' Plot Reliability Growth Analysis Results
 #'
 #' This function generates a plot for the results of a Reliability Growth Analysis (RGA).
@@ -13,14 +11,14 @@
 #' @param conf_bounds Logical indicating whether to include confidence bounds (default: TRUE).
 #' @param legend Logical indicating whether to show the legend (default: TRUE).
 #' @param log Logical indicating whether to use a log-log scale (default: FALSE).
+#' @param legend_pos Position of the legend (default: "bottomright").
 #' @return The function does not return a value.
 #' @examples
 #' times <- c(100, 200, 300, 400, 500)
 #' failures <- c(1, 2, 1, 3, 2)
 #' result <- rga(times, failures)
 #' plot_rga(result)
-#' @importFrom graphics lines abline legend
-#' @export
+#' @importFrom graphics lines abline legend plot
 #' @export
 plot_rga <- function(rga_obj,
                      point_col = "black", line_col = "black",
@@ -28,58 +26,83 @@ plot_rga <- function(rga_obj,
                      main = "Reliability Growth Analysis",
                      conf_bounds = TRUE,
                      legend = TRUE,
-                     log = FALSE) {
+                     log = FALSE,
+                     legend_pos = "bottomright") {
+
+  # Basic input checks
+  if (!inherits(rga_obj, "rga")) stop("Input must be an object of class 'rga'.")
+  if (!is.logical(conf_bounds) || !is.logical(legend) || !is.logical(log)) {
+    stop("Arguments 'conf_bounds', 'legend', and 'log' must be logical.")
+  }
+
+  # Extract original log-log model data
+  if (!all(c("log_times", "log_cum_failures") %in% names(rga_obj$model$model))) {
+    stop("The 'rga_obj' appears malformed or missing model data.")
+  }
 
-  # Extract times and cumulative failures
   times <- exp(rga_obj$model$model$log_times)
   cum_failures <- exp(rga_obj$model$model$log_cum_failures)
 
-  # Set up plot scale
-  plot_args <- list(x = times, y = cum_failures, pch = 16, col = point_col,
-                    xlab = xlab, ylab = ylab, main = main)
+  # Set up base plot
+  plot_args <- list(
+    x = times,
+    y = cum_failures,
+    pch = 16,
+    col = point_col,
+    xlab = xlab,
+    ylab = ylab,
+    main = main
+  )
 
-  if (log) {
-    plot_args$log <- "xy"
-  }
+  if (log) plot_args$log <- "xy"
+  do.call(graphics::plot, plot_args)
 
-  do.call(plot, plot_args)
-
-  # Add the fitted line(s)
+  # Plot fitted values
   graphics::lines(times, rga_obj$fitted_values, col = line_col, lty = 1)
 
-  # Add confidence bounds if requested
+  # Confidence bounds
   if (conf_bounds) {
     graphics::lines(times, rga_obj$lower_bounds, col = line_col, lty = 2)
     graphics::lines(times, rga_obj$upper_bounds, col = line_col, lty = 2)
   }
 
-  # Add vertical lines for change points if present
+  # Change points (breakpoints)
   if (!is.null(rga_obj$breakpoints)) {
     graphics::abline(v = exp(rga_obj$breakpoints), col = "black", lty = 3)
   }
 
-  # Add legend if requested
+  # Legend
   if (legend) {
-    legend_labels <- c("Observed", "Fitted Line")
-    legend_cols <- c(point_col, line_col)
-    legend_pch <- c(16, NA)
-    legend_lty <- c(NA, 1)
+    legend_items <- list(
+      labels = c("Observed", "Fitted Line"),
+      cols = c(point_col, line_col),
+      pch = c(16, NA),
+      lty = c(NA, 1)
+    )
 
     if (conf_bounds) {
-      legend_labels <- c(legend_labels, "Confidence Bounds")
-      legend_cols <- c(legend_cols, line_col)
-      legend_pch <- c(legend_pch, NA)
-      legend_lty <- c(legend_lty, 2)
+      legend_items$labels <- c(legend_items$labels, "Confidence Bounds")
+      legend_items$cols <- c(legend_items$cols, line_col)
+      legend_items$pch <- c(legend_items$pch, NA)
+      legend_items$lty <- c(legend_items$lty, 2)
     }
 
     if (!is.null(rga_obj$breakpoints)) {
-      legend_labels <- c(legend_labels, "Change Points")
-      legend_cols <- c(legend_cols, "black")
-      legend_pch <- c(legend_pch, NA)
-      legend_lty <- c(legend_lty, 3)
+      legend_items$labels <- c(legend_items$labels, "Change Points")
+      legend_items$cols <- c(legend_items$cols, "black")
+      legend_items$pch <- c(legend_items$pch, NA)
+      legend_items$lty <- c(legend_items$lty, 3)
     }
 
-    graphics::legend("bottomright", legend = legend_labels,
-                     col = legend_cols, pch = legend_pch, lty = legend_lty)
+    graphics::legend(
+      legend_pos,
+      legend = legend_items$labels,
+      col = legend_items$cols,
+      pch = legend_items$pch,
+      lty = legend_items$lty,
+      bty = "n"
+    )
   }
+
+  invisible(NULL)
 }
