@@ -18,10 +18,10 @@ plot_rga(result)
 ## -----------------------------------------------------------------------------
 times <- c(25, 55, 97, 146, 201, 268, 341, 423, 513, 609, 710, 820, 940, 1072, 1217)
 failures <- c(1, 1, 2, 4, 4, 1, 1, 2, 1, 4, 1, 1, 3, 3, 4)
-breakpoints <- 500
+breaks <- 500
 
 ## -----------------------------------------------------------------------------
-result <- rga(times, failures, model_type = "Piecewise Weibull NHPP", breakpoints = breakpoints)
+result <- rga(times, failures, model_type = "Piecewise NHPP", breaks = breaks)
 plot_rga(result)
 
 ## -----------------------------------------------------------------------------
@@ -29,7 +29,7 @@ times <- c(25, 55, 97, 146, 201, 268, 341, 423, 513, 609, 710, 820, 940, 1072, 1
 failures <- c(1, 1, 2, 4, 4, 1, 1, 2, 1, 4, 1, 1, 3, 3, 4)
 
 ## -----------------------------------------------------------------------------
-result <- rga(times, failures, model_type = "Piecewise Weibull NHPP")
+result <- rga(times, failures, model_type = "Piecewise NHPP")
 plot_rga(result)
 
 ## -----------------------------------------------------------------------------
